domainParser = require '../../src/main'

domains = [
  'https://developer.domainname.org:8080/en-US/docs/'
  'http://domainname.com:4080/api/bdd/'
  'http://adfadsf-dsdsdsd_fdgf.domainname.com:8030/tutorials/sfadfd-4543534-43543-435-asdfds-4353-24696'
  'http://test.domainname.com.uk.pl/'
]

describe 'domain >>', ->
  #==============================================================================
  # parse url
  #==============================================================================
  it "should have tld url", ->
    expect(domainParser.tldUrl).to.exist

  #==============================================================================
  # pass two arguments
  #==============================================================================
  it "should parse developer.domainname.org", ->
    parsed = domainParser.parse(domains[0])
    expect(parsed.domain).to.exist
    expect(parsed.domain.url).to.equal 'developer.domainname.org:8080'
    expect(parsed.domain.idn).to.equal 'developer.domainname.org'
    expect(parsed.domain.protocol).to.equal 'https'
    expect(parsed.domain.sld).to.equal 'domainname'
    expect(parsed.domain.suffix).to.equal 'org'
    expect(parsed.domain.prefix).to.equal 'developer'
    expect(parsed.domain.port).to.equal '8080'
    expect(parsed.domain.groups.length).to.equal 3
    expect(parsed.domain.token).to.equal 'DeveloperDomainnameOrg'
    expect(parsed.domain.level(2)).to.equal 'domainname'

  it "should parse domainname.com", ->
    parsed = domainParser.parse(domains[1])
    expect(parsed.domain).to.exist
    expect(parsed.domain.url).to.equal 'domainname.com:4080'
    expect(parsed.domain.idn).to.equal 'domainname.com'
    expect(parsed.domain.protocol).to.equal 'http'
    expect(parsed.domain.sld).to.equal 'domainname'
    expect(parsed.domain.suffix).to.equal 'com'
    expect(parsed.domain.prefix).to.equal null
    expect(parsed.domain.port).to.equal '4080'
    expect(parsed.domain.groups.length).to.equal 2
    expect(parsed.domain.token).to.equal 'DomainnameCom'
    expect(parsed.domain.level(2)).to.equal 'domainname'

  it "should parse adfadsf-dsdsdsd_fdgf.domainname.com", ->
    parsed = domainParser.parse(domains[2])
    expect(parsed.domain).to.exist
    expect(parsed.domain.url).to.equal 'adfadsf-dsdsdsd_fdgf.domainname.com:8030'
    expect(parsed.domain.idn).to.equal 'adfadsf-dsdsdsd_fdgf.domainname.com'
    expect(parsed.domain.protocol).to.equal 'http'
    expect(parsed.domain.sld).to.equal 'domainname'
    expect(parsed.domain.suffix).to.equal 'com'
    expect(parsed.domain.prefix).to.equal 'adfadsf-dsdsdsd_fdgf'
    expect(parsed.domain.port).to.equal '8030'
    expect(parsed.domain.groups.length).to.equal 3
    expect(parsed.domain.token).to.equal 'AdfadsfdsdsdsdfdgfDomainnameCom'
    expect(parsed.domain.level(2)).to.equal 'domainname'

  it "should parse test.domainname.com.uk.pl", ->
    parsed = domainParser.parse(domains[3])
    expect(parsed.domain).to.exist
    expect(parsed.domain.url).to.equal 'test.domainname.com.uk.pl'
    expect(parsed.domain.idn).to.equal 'test.domainname.com.uk.pl'
    expect(parsed.domain.protocol).to.equal 'http'
    expect(parsed.domain.sld).to.equal 'domainname'
    expect(parsed.domain.suffix).to.equal 'pl'
    expect(parsed.domain.prefix).to.equal 'test'
    expect(parsed.domain.port).to.equal null
    expect(parsed.domain.groups.length).to.equal 5
    expect(parsed.domain.token).to.equal 'TestDomainnameComUkPl'
    expect(parsed.domain.level(2)).to.equal 'uk'
    